pub struct EmmyrcDiagnostic {
pub disable: Vec<DiagnosticCode>,
pub enable: bool,
pub globals: Vec<String>,
pub globals_regex: Vec<String>,
pub severity: HashMap<DiagnosticCode, DiagnosticSeveritySetting>,
pub enables: Vec<DiagnosticCode>,
pub diagnostic_interval: Option<u64>,
}Expand description
Represents the diagnostic configuration for Emmyrc.
Fields
disable: Vec<DiagnosticCode>A list of diagnostic codes that are disabled.
enable: boolA flag indicating whether diagnostics are enabled.
globals: Vec<String>A list of global variables.
globals_regex: Vec<String>A list of regular expressions for global variables.
severity: HashMap<DiagnosticCode, DiagnosticSeveritySetting>A map of diagnostic codes to their severity settings.
enables: Vec<DiagnosticCode>A list of diagnostic codes that are enabled.
diagnostic_interval: Option<u64>Delay between opening/changing a file and scanning it for errors, in milliseconds.