pub struct EmmyrcDoc {
pub private_name: Vec<String>,
pub known_tags: Vec<String>,
pub syntax: DocSyntax,
pub rst_primary_domain: Option<String>,
pub rst_default_role: Option<String>,
}Fields
private_name: Vec<String>Treat specific field names as private, e.g. m_* means XXX.m_id and XXX.m_type are private, witch can only be accessed in the class where the definition is located.
List of known documentation tags.
syntax: DocSyntaxSyntax for highlighting documentation.
rst_primary_domain: Option<String>When syntax is Myst or Rst, specifies primary domain used
with RST processor.
rst_default_role: Option<String>When syntax is Myst or Rst, specifies default role used
with RST processor.