pub struct EmmyrcExternalTool {
pub program: String,
pub args: Vec<String>,
pub timeout: u64,
}Fields
program: StringThe command to run the external tool.
args: Vec<String>The arguments to pass to the external tool.
timeout: u64Trait Implementations
Sourceimpl Clone for EmmyrcExternalTool
impl Clone for EmmyrcExternalTool
Sourcefn clone(&self) -> EmmyrcExternalTool
fn clone(&self) -> EmmyrcExternalTool
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EmmyrcExternalTool
impl Debug for EmmyrcExternalTool
Sourceimpl Default for EmmyrcExternalTool
impl Default for EmmyrcExternalTool
Sourcefn default() -> EmmyrcExternalTool
fn default() -> EmmyrcExternalTool
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for EmmyrcExternalTool
impl<'de> Deserialize<'de> for EmmyrcExternalTool
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EmmyrcExternalTool
impl JsonSchema for EmmyrcExternalTool
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EmmyrcExternalTool
impl RefUnwindSafe for EmmyrcExternalTool
impl Send for EmmyrcExternalTool
impl Sync for EmmyrcExternalTool
impl Unpin for EmmyrcExternalTool
impl UnwindSafe for EmmyrcExternalTool