pub struct EmmyrcHover {
pub enable: bool,
pub custom_detail: Option<u8>,
}Fields
enable: boolEnable showing documentation on hover.
custom_detail: Option<u8>The detail number of hover information.
Default is None, which means using the default detail level.
You can set it to a number between 1 and 255 to customize