pub struct EmmyrcResource {
pub paths: Vec<String>,
}Fields
paths: Vec<String>Trait Implementations
Sourceimpl Clone for EmmyrcResource
impl Clone for EmmyrcResource
Sourcefn clone(&self) -> EmmyrcResource
fn clone(&self) -> EmmyrcResource
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EmmyrcResource
impl Debug for EmmyrcResource
Sourceimpl Default for EmmyrcResource
impl Default for EmmyrcResource
Sourcefn default() -> EmmyrcResource
fn default() -> EmmyrcResource
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for EmmyrcResource
impl<'de> Deserialize<'de> for EmmyrcResource
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EmmyrcResource
impl JsonSchema for EmmyrcResource
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for EmmyrcResource
impl RefUnwindSafe for EmmyrcResource
impl Send for EmmyrcResource
impl Sync for EmmyrcResource
impl Unpin for EmmyrcResource
impl UnwindSafe for EmmyrcResource