pub struct EmmyrcWorkspace {
pub ignore_dir: Vec<String>,
pub ignore_globs: Vec<String>,
pub library: Vec<EmmyLibraryItem>,
pub package_dirs: Vec<String>,
pub workspace_roots: Vec<String>,
pub preload_file_size: i32,
pub encoding: String,
pub module_map: Vec<EmmyrcWorkspaceModuleMap>,
pub reindex_duration: u64,
pub enable_reindex: bool,
}Fields
ignore_dir: Vec<String>Ignore directories.
ignore_globs: Vec<String>Ignore globs. eg: [“**/*.lua”]
library: Vec<EmmyLibraryItem>Library paths. Can be a string path or an object with path and ignore rules. eg: [“/usr/local/share/lua/5.1”] or [{“path”: “/usr/local/share/lua/5.1”, “ignoreDir”: [“test”], “ignoreGlobs”: [“**/*.spec.lua”]}]
package_dirs: Vec<String>Package directories. Treat the parent directory as a library, but only add files from the specified directory.
eg: /usr/local/share/lua/5.1/module
workspace_roots: Vec<String>Workspace roots. eg: [“src”, “test”]
preload_file_size: i32encoding: StringEncoding. eg: “utf-8”
module_map: Vec<EmmyrcWorkspaceModuleMap>Module map. key is regex, value is new module regex eg: { “^(.)$”: “module_$1” “^lib(.)$”: “script$1” }
reindex_duration: u64Delay between changing a file and full project reindex, in milliseconds.
enable_reindex: boolEnable full project reindex after changing a file.